==> ozacc-mail-1.1-src.tar.gz: ozacc-mail-1.1/src/java/com/ozacc/mail/mock/EqualityCheck.java <==
package com.ozacc.mail.mock;

import javax.mail.internet.InternetAddress;

import com.ozacc.mail.Mail;

/**
 * ᡼뤬ƱͤǤ뤳ȤĴ٤᥽åɤ󶡡
 * <p>
 * <strong>:</strong> źեեоݤˤʤޤ
 * 
 * @since 1.1
 * 
 * @author Tomohiro Otsuka
 * @version $Id: EqualityCheck.java,v 1.3 2004/09/22 05:56:00 otsuka Exp $
 */
public class EqualityCheck {

	private EqualityCheck() {}

	/**
	 * expectedsentΥ᡼ƤƱǤ뤫ɤȽꤷޤ<br>
	 * MultipartMailΥ󥹥󥹤Ǥޤâźեեϥåޤ
	 * 
	 * @param expected
	 * @param sent
	 * @return expectedsentΥ᡼ƤƱǤ true
	 */
	public static boolean equals(Mail expected, Mail sent) {
		boolean mockMode = false;
		if (expected instanceof MockMail) {
			mockMode = true;
		}

		// ޥѡȥ᡼ξ
		if (expected.isMultipartMail()) {

			// HTML
			if (!mockMode) {
				if ((expected.getHtmlText() == null && sent.getHtmlText() != null)
						|| (expected.getHtmlText() != null && sent.getHtmlText() == null)
						|| (!expected.getHtmlText().equals(sent.getHtmlText()))) {
					return false;
				}
			} else if (mockMode && expected.getHtmlText() != null) {
				if (!expected.getHtmlText().equals(sent.getHtmlText())) {
					return false;
				}
			}
		}

		// Return-Path
		if (!mockMode || (mockMode && expected.getReturnPath() != null)) {
			if (expected.getReturnPath() != null && sent.getReturnPath() != null) {
				if (!expected.getReturnPath().equals(sent.getReturnPath())) {
					return false;
				}
			} else if ((expected.getReturnPath() != null && sent.getReturnPath() == null)
					|| (expected.getReturnPath() == null && sent.getReturnPath() != null)) {
				return false;
			}
		}

		// to
		InternetAddress[] expectedAddresses = expected.getTo();
		InternetAddress[] sentAddresses = sent.getTo();
		if (!mockMode || (mockMode && expectedAddresses.length > 0)) {
			if (expectedAddresses.length != sentAddresses.length) {
				return false;
			}
			for (int i = 0; i < expectedAddresses.length; i++) {
				if (!expectedAddresses[i].equals(sentAddresses[i])) {
					return false;
				}
			}
		}

		// cc
		expectedAddresses = expected.getCc();
		sentAddresses = sent.getCc();
		if (!mockMode || (mockMode && expectedAddresses.length > 0)) {
			if (expectedAddresses.length != sentAddresses.length) {
				return false;
			}
			for (int i = 0; i < expectedAddresses.length; i++) {
				if (!expectedAddresses[i].equals(sentAddresses[i])) {
					return false;
				}
			}
		}

		// bcc
		expectedAddresses = expected.getBcc();
		sentAddresses = sent.getBcc();
		if (!mockMode || (mockMode && expectedAddresses.length > 0)) {
			if (expectedAddresses.length != sentAddresses.length) {
				return false;
			}
			for (int i = 0; i < expectedAddresses.length; i++) {
				if (!expectedAddresses[i].equals(sentAddresses[i])) {
					return false;
				}
			}
		}

		// Reply-To
		if (!mockMode || (mockMode && expected.getReplyTo() != null)) {
			if (expected.getReplyTo() != null && sent.getReplyTo() != null) {
				if (!expected.getReplyTo().equals(sent.getReplyTo())) {
					return false;
				}
			} else if ((expected.getReplyTo() != null && sent.getReplyTo() == null)
					|| (expected.getReplyTo() == null && sent.getReplyTo() != null)) {
				return false;
			}
		}

		// ̾
		if (!mockMode || (mockMode && expected.getSubject().length() > 0)) {
			if (!expected.getSubject().equals(sent.getSubject())) {
				return false;
			}
		}

		// ʸ
		if (!mockMode || (mockMode && expected.getText().length() > 0)) {
			if (!expected.getText().equals(sent.getText())) {
				return false;
			}
		}

		return true;
	}
}

==> ozacc-mail-1.1.7-src.tar.gz: ozacc-mail-1.1.7/src/java/com/ozacc/mail/mock/EqualityCheck.java <==
package com.ozacc.mail.mock;

import javax.mail.internet.InternetAddress;

import com.ozacc.mail.Mail;

/**
 * ᡼뤬ƱͤǤ뤳ȤĴ٤᥽åɤ󶡡
 * <p>
 * <strong>:</strong> źեեоݤˤʤޤ
 * 
 * @since 1.1
 * 
 * @author Tomohiro Otsuka
 * @version $Id: EqualityCheck.java,v 1.5 2004/10/31 04:33:33 otsuka Exp $
 */
public class EqualityCheck {

	private EqualityCheck() {}

	/**
	 * expectedsentΥ᡼ƤƱǤ뤫ɤȽꤷޤ<br>
	 * MultipartMailΥ󥹥󥹤Ǥޤâźեեϥåޤ
	 * 
	 * @param expected
	 * @param sent
	 * @return expectedsentΥ᡼ƤƱǤ true
	 */
	public static boolean equals(Mail expected, Mail sent) {
		boolean mockMode = (expected instanceof MockMail);

		// ޥѡȥ᡼ξ
		if (expected.isMultipartMail()) {

			// HTML
			if (!mockMode) {
				if ((expected.getHtmlText() == null && sent.getHtmlText() != null)
						|| (expected.getHtmlText() != null && sent.getHtmlText() == null)
						|| (!expected.getHtmlText().equals(sent.getHtmlText()))) {
					return false;
				}
			} else if (mockMode && expected.getHtmlText() != null) {
				if (!expected.getHtmlText().equals(sent.getHtmlText())) {
					return false;
				}
			}
		}

		// Return-Path
		if (!mockMode || (mockMode && expected.getReturnPath() != null)) {
			if (expected.getReturnPath() != null && sent.getReturnPath() != null) {
				if (!expected.getReturnPath().equals(sent.getReturnPath())) {
					return false;
				}
			} else if ((expected.getReturnPath() != null && sent.getReturnPath() == null)
					|| (expected.getReturnPath() == null && sent.getReturnPath() != null)) {
				return false;
			}
		}

		//	From
		if (!mockMode || (mockMode && expected.getFrom() != null)) {
			if (expected.getFrom() != null && sent.getFrom() != null) {
				if (!equals(expected.getFrom(), sent.getFrom())) {
					return false;
				}
			} else if ((expected.getFrom() != null && sent.getFrom() == null)
					|| (expected.getFrom() == null && sent.getFrom() != null)) {
				return false;
			}
		}

		// to
		InternetAddress[] expectedAddresses = expected.getTo();
		InternetAddress[] sentAddresses = sent.getTo();
		if (!mockMode || (mockMode && expectedAddresses.length > 0)) {
			if (expectedAddresses.length != sentAddresses.length) {
				return false;
			}
			for (int i = 0; i < expectedAddresses.length; i++) {
				if (!equals(expectedAddresses[i], sentAddresses[i])) {
					return false;
				}
			}
		}

		// cc
		expectedAddresses = expected.getCc();
		sentAddresses = sent.getCc();
		if (!mockMode || (mockMode && expectedAddresses.length > 0)) {
			if (expectedAddresses.length != sentAddresses.length) {
				return false;
			}
			for (int i = 0; i < expectedAddresses.length; i++) {
				if (!equals(expectedAddresses[i], sentAddresses[i])) {
					return false;
				}
			}
		}

		// bcc
		expectedAddresses = expected.getBcc();
		sentAddresses = sent.getBcc();
		if (!mockMode || (mockMode && expectedAddresses.length > 0)) {
			if (expectedAddresses.length != sentAddresses.length) {
				return false;
			}
			for (int i = 0; i < expectedAddresses.length; i++) {
				if (!equals(expectedAddresses[i], sentAddresses[i])) {
					return false;
				}
			}
		}

		// Reply-To
		if (!mockMode || (mockMode && expected.getReplyTo() != null)) {
			if (expected.getReplyTo() != null && sent.getReplyTo() != null) {
				if (!equals(expected.getReplyTo(), sent.getReplyTo())) {
					return false;
				}
			} else if ((expected.getReplyTo() != null && sent.getReplyTo() == null)
					|| (expected.getReplyTo() == null && sent.getReplyTo() != null)) {
				return false;
			}
		}

		// ̾
		if (!mockMode || (mockMode && expected.getSubject().length() > 0)) {
			if (!expected.getSubject().equals(sent.getSubject())) {
				return false;
			}
		}

		// ʸ
		if (!mockMode || (mockMode && expected.getText().length() > 0)) {
			if (!expected.getText().equals(sent.getText())) {
				return false;
			}
		}

		return true;
	}

	/**
	 * ꤵ줿ĤInternetAddress󥹥󥹤ɤȽꤷޤ
	 * <p>
	 * InternetAddress#equals()᥽åɤǤϡ᡼륢ɥ쥹ʤᡢ
	 * Υ᥽åɤǤInternetAddress̾ޤޤƤ硢̾
	 * ɤޤ
	 * 
	 * @since 1.1.3
	 * @param a ӤInternetAddress󥹥
	 * @param b ӤInternetAddress󥹥
	 * @return ĤInternetAddress󥹥󥹤 true
	 */
	public static boolean equals(InternetAddress a, InternetAddress b) {
		if (a.equals(b)) {
			if (a.getPersonal() != null || b.getPersonal() != null) {
				return a.getPersonal().equals(b.getPersonal());
			} else {
				return true;
			}
		}
		return false;
	}
}
